package Locale::CLDR::Zgh::Any v0.25.0;
# This file auto generated
#	on Tue 22 Apr 12:57:28 am GMT

use v5.18;
use mro 'c3';

use Moose;

extends('Locale::CLDR::Zgh');

no Moose;
__PACKAGE__->meta->make_immutable;
